sdv.metrics.tabular.SVCDetection
================================

.. currentmodule:: sdv.metrics.tabular

.. autoclass:: SVCDetection

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SVCDetection.__init__
      ~SVCDetection.compute
      ~SVCDetection.compute_breakdown
      ~SVCDetection.get_subclasses
      ~SVCDetection.normalize
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SVCDetection.goal
      ~SVCDetection.max_value
      ~SVCDetection.min_value
      ~SVCDetection.name
   
   